@@ -27,7 +27,7 @@ plot_mpp <- function(mpp_data, pattern_type) {
     stop("Provide a valid pattern type ('reference' or 'simulated').", .call = FALSE)
   }
 
-  mpp_plot <- base::as.data.frame(mpp_data) |>
+  mpp_plot <- base::as.data.frame(mpp_data) %>%
     ggplot2::ggplot(ggplot2::aes(x = mpp_data$x, y = mpp_data$y, size = mpp_data$marks)) +
     ggplot2::geom_point(alpha = .5) +
     ggplot2::labs(x = "", y = "", title = plot_title, size = "Mark")
